.. _faq:

Frequently Asked Questions
==========================

Here are some questions we get often. Please suggest more by raising an 
issue in the `Github Issue Tracker <https://github.com/sblunt/orbitize/issues>`_.

**What is τ and how is it related to epoch of periastron?**

We use τ to define the epoch of periastron as we do not know when periastron will be for many of our directly
imaged planets. A detailed description of how τ is related to other quantities such as :math:`t_p` is available:

.. toctree::
   :maxdepth: 1

   faq/Time_Of_Periastron.ipynb




